summaryrefslogtreecommitdiff
path: root/src/dummy
diff options
context:
space:
mode:
authorRichard Hughes <richard@hughsie.com>2010-01-18 12:35:47 +0000
committerRichard Hughes <richard@hughsie.com>2010-01-18 12:35:47 +0000
commitd2550b4c7854e970719b07b48ecdb61af9c01b6f (patch)
tree59ba56384fee7aaf7a25857556a6a3dec87c8758 /src/dummy
parent2562bc6aa6fe9b5f422e01c92aef9745bed5204f (diff)
downloadupower-d2550b4c7854e970719b07b48ecdb61af9c01b6f.tar.gz
trivial: DkpDaemon -> UpDaemon (no ABI or API break)
Diffstat (limited to 'src/dummy')
-rw-r--r--src/dummy/up-backend.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/dummy/up-backend.c b/src/dummy/up-backend.c
index 1253c40..23e063c 100644
--- a/src/dummy/up-backend.c
+++ b/src/dummy/up-backend.c
@@ -42,7 +42,7 @@ static void up_backend_finalize (GObject *object);
struct UpBackendPrivate
{
- DkpDaemon *daemon;
+ UpDaemon *daemon;
DkpDevice *device;
DkpDeviceList *device_list; /* unused */
GObject *native;
@@ -103,7 +103,7 @@ out:
/**
* up_backend_coldplug:
* @backend: The %UpBackend class instance
* @daemon: The %DkpDaemon controlling instance
*
* Finds all the devices already plugged in, and emits device-add signals for
* each of them.
@@ -111,10 +111,10 @@ out:
* Return value: %TRUE for success
**/
gboolean
-up_backend_coldplug (UpBackend *backend, DkpDaemon *daemon)
+up_backend_coldplug (UpBackend *backend, UpDaemon *daemon)
{
backend->priv->daemon = g_object_ref (daemon);
- backend->priv->device_list = dkp_daemon_get_device_list (daemon);
+ backend->priv->device_list = up_daemon_get_device_list (daemon);
/* small delay until first device is added */
g_timeout_add_seconds (1, (GSourceFunc) up_backend_add_cb, backend);
@@ -103,7 +103,7 @@ out:
* up_backend_coldplug:
* @backend: The %UpBackend class instance
- * @daemon: The %DkpDaemon controlling instance
+ * @daemon: The %UpDaemon controlling instance
*
* Finds all the devices already plugged in, and emits device-add signals for